@@ -1,6 +1,7 @@
 import os
 
 from pyotrs import Client
+from pyotrs.lib import DynamicField
 from pyotrs.lib import APIError, HTTPError, ResponseParseError, SessionNotCreated, ArgumentMissingError
 
 from otrs_somconnexio.responses.ticket_creation import OTRSCreationTicketResponse
@@ -13,6 +14,30 @@ from otrs_somconnexio.exceptions import TicketNotCreated, ErrorCreatingSession,
 
 
 class OTRSClient():
+    TICKET_CONNECTOR_CONFIG = {
+        'Name': 'GenericTicketConnectorREST',
+        'Config': {
+            'SessionCreate': {'RequestMethod': 'POST',
+                              'Route': '/Session',
+                              'Result': 'SessionID'},
+            'TicketCreate': {'RequestMethod': 'POST',
+                             'Route': '/Ticket',
+                             'Result': 'TicketID'},
+            'TicketGet': {'RequestMethod': 'GET',
+                          'Route': '/Ticket/:TicketID',
+                          'Result': 'Ticket'},
+            'TicketGetList': {'RequestMethod': 'GET',
+                              'Route': '/TicketList',
+                              'Result': 'Ticket'},
+            'TicketSearch': {'RequestMethod': 'POST',
+                             'Route': '/TicketSearch',
+                             'Result': 'TicketID'},
+            'TicketUpdate': {'RequestMethod': 'PATCH',
+                             'Route': '/Ticket/:TicketID',
+                             'Result': 'TicketID'},
+        }
+    }
+
     def __init__(self):
         self.client = self._create_client_with_session()
 
@@ -40,7 +65,9 @@ class OTRSClient():
             client = Client(
                 baseurl=self._url(),
                 username=self._user(),
-                password=self._password())
+                password=self._password(),
+                webservice_config_ticket=self.TICKET_CONNECTOR_CONFIG
+            )
             client.session_create()
         except (HTTPError, APIError, ResponseParseError) as error:
             raise ErrorCreatingSession(error.message)
@@ -94,6 +121,19 @@ class OTRSClient():
 
         return tickets
 
+    def search_coverage_tickets_by_email(self, email):
+        df_process_id = {
+            "name": "ProcessManagementProcessID",
+            "value": "Process-be8cf222949132c9fae1bb74615a5ae4"
+        }
+
+        return self.search_tickets(
+            dynamic_fields=[
+                DynamicField(df_process_id["name"], search_patterns=[df_process_id["value"]]),
+                DynamicField("correuElectronic", search_patterns=[email])
+            ]
+        )
+
     def update_ticket(self, ticket_id, article):
         self.client.ticket_update(ticket_id, article)
 
