@@ -1,6 +1,6 @@
 from otrs_somconnexio.ticket_exceptions import ServiceTypeNotAllowedError
-from otrs_somconnexio.otrs_models.ticket_adsl import ADSLTicket
-from otrs_somconnexio.otrs_models.ticket_fibre import FibreTicket
+from otrs_somconnexio.otrs_models.adsl_ticket import ADSLTicket
+from otrs_somconnexio.otrs_models.fiber_ticket import FiberTicket
 from otrs_somconnexio.otrs_models.mobile_ticket import MobileTicket
 
 
@@ -21,8 +21,10 @@ class TicketFactory(object):
         if self.contract_type == 'adsl':
             ticket = ADSLTicket(self.econtract, self.otrs_configuration)
         elif self.contract_type == 'fiber':
-            ticket = FibreTicket(self.econtract, self.otrs_configuration)
+            ticket = FiberTicket(self.econtract, self.otrs_configuration)
         elif self.contract_type == 'mobile':
             ticket = MobileTicket(self.econtract, self.otrs_configuration)
 
+        ticket.create()
+
         return ticket
